@@ -37,6 +37,7 @@ server_defender_upstart=defender-server.conf
 onebox_component=onebox
 console_component=console
 defender_component_docker=defender
+defender_component_podman=defender-podman
 defender_component_linux_server=defender-server
 defender_component_tas=defender-tas
 
@@ -125,6 +126,13 @@ set_docker_command_on_defender_stop() {
 
 # Sets the docker command to variable 'docker' by testing naively the possible docker sockets
 set_docker_command() {
+	local component=${1}
+	if [ "${component}" == "${defender_component_podman}" ]; then
+		docker="podman"
+		print_debug "setting initial docker command to ${docker}"
+		return
+	fi
+
 	is_valid_docker_socket ${new_docker_socket}
 	if [[ $? == 0 ]]; then
 		docker="docker -H unix://${new_docker_socket}"
@@ -656,6 +664,7 @@ install_defender() {
 	local console_address=${1}
 	local registry_enabled=${2}
 	local install_bundle=${3}
+	local component=${4}
 
 	if command_exists systemctl; then
 		systemctl is-enabled ${server_defender_service} >/dev/null 2>&1
@@ -737,8 +746,14 @@ install_defender() {
 			--cap-add=SYS_CHROOT \
 			--cap-add=IPC_LOCK "
 
+	if [ "${component}" == "${defender_component_podman}" ]; then
+		additional_env+=" -e DEFENDER_TYPE=podman "
+	fi
+
 	if is_podman; then
-		additional_env+=" -e DEFENDER_TYPE=cri "
+		if [ "${component}" != "${defender_component_podman}" ]; then
+			additional_env+=" -e DEFENDER_TYPE=cri "
+		fi
 		# MKNOD - a capability to create special files using mknod(2), used by docker-less registry scanning
 		# SETFCAP - a capability to set file capabilities, used by docker-less registry scanning
 		caps+=" --cap-add=MKNOD \
@@ -1092,7 +1107,7 @@ load_images() {
 		remove_container "twistlock_data"
 	fi
 
-	if [[ ${component} == "" || ${component} == "${onebox_component}" || ${component} == "${defender_component_docker}" ]]; then
+	if [[ ${component} == "" || ${component} == "${onebox_component}" || ${component} == "${defender_component_docker}" || ${component} == "${defender_component_podman}" ]]; then
 		# Skip if image is loaded
 		if [[ "$(${docker} images | awk '{print $1":"$2}' | grep ${defender_image} 2>/dev/null)" == "" ]]; then
 
@@ -1315,6 +1330,10 @@ while getopts "${optspec}" opt; do
 			ws_port="${!OPTIND}"
 			OPTIND=$((${OPTIND} + 1))
 			;;
+		podman-socket)
+			additional_env+=" -e PODMAN_CLIENT_ADDRESS=${!OPTIND}"
+			OPTIND=$((${OPTIND} + 1))
+			;;
 		env)
 			additional_env+=" -e ${!OPTIND} "
 			OPTIND=$((${OPTIND} + 1))
@@ -1422,6 +1441,7 @@ if (
 	[[ -z "${custom}" ]] &&
 		[ "${component}" != "${onebox_component}" ] &&
 		[ "${component}" != "${defender_component_docker}" ] &&
+		[ "${component}" != "${defender_component_podman}" ] &&
 		[ "${component}" != "${defender_component_linux_server}" ] &&
 		[ "${component}" != "${defender_component_tas}" ] &&
 		[ "${component}" != "${console_component}" ] &&
@@ -1490,7 +1510,7 @@ if [[ "${component}" == "${defender_component_tas}" ]]; then
 	exit
 fi
 
-set_docker_command
+set_docker_command ${component}
 set_docker_version
 
 min_version=1.7
@@ -1570,13 +1590,14 @@ if [ "${component}" == "${onebox_component}" ]; then
 	print_info "Installation completed successfully"
 fi
 
-if [ "${component}" == "${defender_component_docker}" ]; then
+if [ "${component}" == "${defender_component_docker}" ] ||
+	[ ${component} == "${defender_component_podman}" ]; then
 	if [ -z "${console_address}" ]; then
 		print_error "Console address parameter must be provided"
 		exit
 	fi
 
-	install_defender "${console_address}" "${registry_enabled}" "${install_bundle}"
+	install_defender "${console_address}" "${registry_enabled}" "${install_bundle}" "${component}"
 	exit
 fi
 
